function eps_tm_wr_stored_param_dissector(buffer, pinfo, tree, eps_proto, offset)

    local f_sub_option = ProtoField.uint8("eps.sub_option", "Sub-Option", base.DEC)
    local f_status = ProtoField.uint8("eps.status", "Status (0-Success, 1-Fail)", base.DEC)
    local f_conv_brd_error = ProtoField.int8("eps.conv_brd_error", "Converter Board Error Code  ", base.DEC)
    local f_btry_brd_error = ProtoField.int8("eps.btry_brd_error", "Battery Board Error Code  ", base.DEC)
    local f_op_chnl_brd_error = ProtoField.int8("eps.op_chnl_brd_error", "OP Channel Board Error Code  ", base.DEC)
    local f_btry_thrshld_error = ProtoField.int8("eps.btry_thrshld_error", "Battery Threshold Error Code  ", base.DEC)
    local f_com_fail_error = ProtoField.int8("eps.com_fail_error", "Communication Failure Error Code : ", base.DEC)
    local f_rtc_time_status = ProtoField.int8("eps.rtc_time_status", "RTC Time Status  ", base.DEC)
    local f_chnl_err_code = ProtoField.int8("eps.chnl_err_code", "Channel Error code  ", base.DEC)
    
  eps_proto.fields = {f_sub_option, f_status, f_conv_brd_error, f_btry_brd_error, 
  f_op_chnl_brd_error, f_btry_thrshld_error, f_com_fail_error, f_rtc_time_status, f_chnl_err_code}
  
  local subtree = tree:add(eps_proto, buffer(), "EPS WR STORED PARAM")
  
    local option = buffer(offset, 1):le_uint()
    subtree:add(f_sub_option, buffer(offset, 1))
    offset = offset + 1
    
    local error_descriptions = {
    [0] = " (EPS_SUCCESS)",
    [-1] = " (EPS_CRC_FAIL)",
    [-2] = " (EPS_ERR)",
    [-3] = " (EPS_COM_FAIL)",
    [-4] = " (EPS_INVLD_ARG)",
    [-5] = " (EPS_NULL_PTR_ERR)",
    [-6] = " (EPS_SET_PARAM_ERR)",
    [-7] = " (EPS_RESP_ERR)",
    [-8] = " (ERR_FW_UPDATE_PROG)"
    
    }

    
    if option == 0 then
      local status = buffer(offset, 1):uint()
      subtree:add(f_status, buffer(offset, 1)):append_text(status == 0 and " (Success)" or " (Fail)")
      offset = offset + 1
      
       -- Parse Error Codes
    local error_fields = {
        {field = f_conv_brd_error, name = "Converter Board"},
        {field = f_btry_brd_error, name = "Battery Board"},
        {field = f_op_chnl_brd_error, name = "OP Channel Board"},
        {field = f_btry_thrshld_error, name = "Battery Threshold"},
        {field = f_com_fail_error, name = "Communication Failure"}
    }

    for _, err_field in ipairs(error_fields) do
        local error_code = buffer(offset, 1):le_int()
        subtree:add(err_field.field, buffer(offset, 1):le_int()):append_text(error_descriptions[error_code])
        offset = offset + 1
    end
    
    elseif option == 1 then
      local status = buffer(offset, 1):uint()
      subtree:add(f_status, buffer(offset, 1)):append_text(status == 0 and " (Success)" or " (Fail)")
      offset = offset + 1
      
      local error_code = buffer(offset, 1):le_int()
      subtree:add(f_rtc_time_status, buffer(offset, 1):le_int()):append_text(error_descriptions[error_code])
      
    elseif option == 2 then
      local status = buffer(offset, 1):uint()
      subtree:add(f_status, buffer(offset, 1)):append_text(status == 0 and " (Success)" or " (Fail)")
      offset = offset + 1
      
      local error_code = buffer(offset, 1):le_int()
      subtree:add(f_chnl_err_code, buffer(offset, 1):le_int()):append_text(error_descriptions[error_code])
    end
end
      
      