function tm_comms_uhf_get_tm_store(buffer, pinfo, tree, comms_uhf_tm_store, offset)
    -- Define ProtoFields for the structure
    local f_timestamp = ProtoField.uint64("comms_uhf_tm_store.timestamp", "Timestamp", base.DEC)
    local f_adc_cnt = ProtoField.uint8("comms_uhf_tm_store.adc_cnt", "ADC Count", base.DEC)
    local f_uptime = ProtoField.uint32("comms_uhf_tm_store.uptime", "Device Uptime", base.DEC)
    local f_uart0_rx_count = ProtoField.uint32("comms_uhf_tm_store.uart0_rx_count", "UART0 RX Count", base.DEC)
    local f_uart1_rx_count = ProtoField.uint32("comms_uhf_tm_store.uart1_rx_count", "UART1 RX Count", base.DEC)
    local f_rx_mode = ProtoField.uint8("comms_uhf_tm_store.rx_mode", "RX Mode", base.DEC)
    local f_tx_mode = ProtoField.uint8("comms_uhf_tm_store.tx_mode", "TX Mode", base.DEC)
    local f_adc = ProtoField.int16("comms_uhf_tm_store.adc", "ADC Channel Stat", base.DEC)
    local f_last_rssi = ProtoField.int8("comms_uhf_tm_store.last_rssi", "Last RSSI", base.DEC)
    local f_last_lqi = ProtoField.uint8("comms_uhf_tm_store.last_lqi", "Last LQI", base.DEC)
    local f_last_freqest = ProtoField.int8("comms_uhf_tm_store.last_freqest", "Last Frequency Estimation", base.DEC)
    local f_pkt_sent = ProtoField.uint32("comms_uhf_tm_store.pkt_sent", "Packets Sent", base.DEC)
    local f_cs_count = ProtoField.uint32("comms_uhf_tm_store.cs_count", "CS Count", base.DEC)
    local f_pkt_good = ProtoField.uint32("comms_uhf_tm_store.pkt_good", "Packets Good", base.DEC)
    local f_pkt_rejected_checksum = ProtoField.uint32("comms_uhf_tm_store.pkt_rejected_checksum", "Packets Rejected (Checksum)", base.DEC)
    local f_pkt_rejected_reserved = ProtoField.uint32("comms_uhf_tm_store.pkt_rejected_reserved", "Packets Rejected (Reserved)", base.DEC)
    local f_pkt_rejected_other = ProtoField.uint32("comms_uhf_tm_store.pkt_rejected_other", "Packets Rejected (Other)", base.DEC)
    local f_reserved0 = ProtoField.uint32("comms_uhf_tm_store.reserved0", "Reserved 1", base.DEC)
    local f_data_tx_cnt = ProtoField.uint32("comms_uhf_tm_store.data_tx_cnt", "Data uart tx cnt", base.DEC)
    local f_data_rx_cnt = ProtoField.uint32("comms_uhf_tm_store.data_rx_cnt","Data uart rx cnt", base.DEC)

    -- Add fields to the protocol
    comms_uhf_tm_store.fields = { 
        f_timestamp,
        f_adc_cnt,
        f_uptime,
        f_uart0_rx_count,
        f_uart1_rx_count,
        f_rx_mode,
        f_tx_mode,
        f_adc,
        f_last_rssi,
        f_last_lqi,
        f_last_freqest,
        f_pkt_sent,
        f_cs_count,
        f_pkt_good,
        f_pkt_rejected_checksum,
        f_pkt_rejected_reserved,
        f_pkt_rejected_other,
        f_reserved0,
        f_data_tx_cnt,
        f_data_rx_cnt
    }

    -- Add a subtree for the structure
    local subtree = tree:add(comms_uhf_tm_store, buffer(), "TM COMMS UHF GET TM STORE")

    -- Dissect each field
    -- ADC Count (1 byte)
    local adc_cnt = buffer(offset, 1):le_uint()
    subtree:add(f_adc_cnt, buffer(offset, 1)):set_text(string.format("ADC Count: %d", adc_cnt))
    offset = offset + 1
    
    for i = 0, adc_cnt - 1 do
    local subtree1 = subtree:add(comms_uhf_tm_store, buffer(), "INSTANCE"..i)
    -- Timestamp
    subtree1:add(f_timestamp, buffer(offset, 8):le_uint64())
    offset = offset + 8

    -- Device Uptime (4 bytes)
    subtree1:add_le(f_uptime, buffer(offset, 4):le_uint())
    offset = offset + 4

    -- UART0 RX Count (4 bytes)
    subtree1:add_le(f_uart0_rx_count, buffer(offset, 4):le_uint())
    offset = offset + 4

    -- UART1 RX Count (4 bytes)
    subtree1:add_le(f_uart1_rx_count, buffer(offset, 4):le_uint())
    offset = offset + 4

    -- RX Mode (1 byte)
    subtree1:add(f_rx_mode, buffer(offset, 1):le_uint())
    offset = offset + 1

    -- TX Mode (1 byte)
    subtree1:add(f_tx_mode, buffer(offset, 1):le_uint())
    offset = offset + 1

    -- ADC Channel Stat (10 * 2 bytes)
    --local adc_subtree = subtree:add(buffer(offset, adc_cnt * 2), "ADC Channel Stats")
    for i = 0, 10 - 1 do
        local adc_value = buffer(offset, 2):le_int()
        subtree1:add(f_adc, buffer(offset, 2)):set_text(string.format("ADC[%d]: %d", i + 1, adc_value))
        offset = offset + 2
    end

    -- Last RSSI (1 byte)
    subtree1:add(f_last_rssi, buffer(offset, 1):le_uint())
    offset = offset + 1

    -- Last LQI (1 byte)
    subtree1:add(f_last_lqi, buffer(offset, 1):le_uint())
    offset = offset + 1

    -- Last Frequency Estimation (1 byte)
    subtree1:add(f_last_freqest, buffer(offset, 1):le_uint())
    offset = offset + 1

    -- Packets Sent (4 bytes)
    subtree1:add_le(f_pkt_sent, buffer(offset, 4):le_uint())
    offset = offset + 4

    -- CS Count (4 bytes)
    subtree1:add_le(f_cs_count, buffer(offset, 4):le_uint())
    offset = offset + 4

    -- Packets Good (4 bytes)
    subtree1:add_le(f_pkt_good, buffer(offset, 4):le_uint())
    offset = offset + 4

    -- Packets Rejected (Checksum) (4 bytes)
    subtree1:add_le(f_pkt_rejected_checksum, buffer(offset, 4):le_uint())
    offset = offset + 4

    -- Packets Rejected (Reserved) (4 bytes)
    subtree1:add_le(f_pkt_rejected_reserved, buffer(offset, 4):le_uint())
    offset = offset + 4

    -- Packets Rejected (Other) (4 bytes)
    subtree1:add_le(f_pkt_rejected_other, buffer(offset, 4):le_uint())
    offset = offset + 4

    --Reserved 0 (4 bytes)
    subtree1:add_le(f_reserved0, buffer(offset, 1):le_uint())
    offset = offset + 1

    -- Custom 0 (4 bytes)
    subtree1:add_le(f_data_tx_cnt, buffer(offset, 4):le_uint())
    offset = offset + 4

    -- Custom 1 (4 bytes)
    subtree1:add_le(f_data_rx_cnt, buffer(offset, 4))
    offset = offset + 4
    end

end
