function tm_get_adcs_mag_field_vector(buffer, pinfo, tree, adcs_magnetic_field, offset, num_of_instance)

local f_magnetic_field_x = ProtoField.float("adcs_magnetic_field.magnetic_field_x", "X Axis Magnetic Field Vector", base.DEC)
local f_magnetic_field_y = ProtoField.float("adcs_magnetic_field.magnetic_field_y", "Y Axis Magnetic Field Vector", base.DEC)
local f_magnetic_field_z = ProtoField.float("adcs_magnetic_field.magnetic_field_z", "Z Axis Magnetic Field Vector", base.DEC)

-- Add the protocol fields to the protocol
adcs_magnetic_field.fields = {
    f_magnetic_field_x,
    f_magnetic_field_y,
    f_magnetic_field_z
}

local subtree = tree:add(adcs_magnetic_field, buffer(), "ADCS MAGNETIC FIELD VECTOR")
    
    offset = offset + 3
    local data = buffer(offset,1):le_int()
    offset = offset + 1 
    if data == 0 then
    -- X Axis Magnetic Field Vector (2 bytes, INT)
    local x_field = buffer(offset, 4):le_float()  -- Apply the scaling factor (RAWVAL * 0.01)
    subtree:add(f_magnetic_field_x, x_field):set_text(string.format("X Axis Magnetic Field Vector : %3.6f",x_field))
    offset = offset + 4  -- Update offset

    -- Y Axis Magnetic Field Vector (2 bytes, INT)
    local y_field = buffer(offset, 4):le_float() -- Apply the scaling factor (RAWVAL * 0.01)
    subtree:add(f_magnetic_field_y, y_field):set_text(string.format("Y Axis Magnetic Field Vector : %3.6f",y_field))
    offset = offset + 4  -- Update offset

    -- Z Axis Magnetic Field Vector (2 bytes, INT)
    local z_field = buffer(offset, 4):le_float()   -- Apply the scaling factor (RAWVAL * 0.01)
    subtree:add(f_magnetic_field_z, z_field):set_text(string.format("Z Axis Magnetic Field Vector : %3.6f",z_field))
    offset = offset + 4  -- Update offset
    
    elseif data == -1 then
    subtree:add(" ADCS operation failure ")
    elseif data == -2 then
    subtree:add(" TC TM error ")
    elseif data == -3 then
    subtree:add(" Interface error ")
    elseif data == -4 then
    subtree:add(" Id not support ")
    elseif data == -5 then
    subtree:add(" ADCS HW in invalid power state ")
    elseif data == -6 then
    subtree:add(" ADCS Semaphore take failure ")
    elseif data == -6 then
    subtree:add(" ADCS Operating Mode Mismatch error ")
    elseif data == -6 then
    subtree:add(" ADCS responded data is not in a valid range ")
    end
    
end