function tm_get_sband_tx_rx_on_ts(buffer, pinfo, tree, sband_tx_rx_sts_timestamp, offset)
    -- Define ProtoFields for s_sband_rx_sts_timestamp
    local f_rx0_sts = ProtoField.uint8("sband_rx_sts_timestamp.rx0_sts", "Rx0 Status", base.DEC)
    local f_rx1_sts = ProtoField.uint8("sband_rx_sts_timestamp.rx1_sts", "Rx1 Status", base.DEC)
    local f_timestamp_rx = ProtoField.uint64("sband_rx_sts_timestamp.timestamp", "Timestamp", base.DEC)

    -- Define ProtoFields for s_sband_tx_sts_timestamp
    local f_tx_sts = ProtoField.uint8("sband_tx_sts_timestamp.tx_sts", "Tx Status", base.DEC)
    local f_timestamp_tx = ProtoField.uint64("sband_tx_sts_timestamp.timestamp", "Timestamp", base.DEC)

    -- Define ProtoFields for s_sband_tx_rx_sts_timestamp
    local f_tx_index = ProtoField.uint16("sband_tx_rx_sts_timestamp.tx_index", "Tx Index", base.DEC)
    local f_rx_index = ProtoField.uint16("sband_tx_rx_sts_timestamp.rx_index", "Rx Index", base.DEC)
    
    -- Register the fields in the protocol
    sband_tx_rx_sts_timestamp.fields = {
        f_tx_index, f_rx_index, 
        f_tx_sts, f_timestamp_tx, 
        f_rx0_sts, f_rx1_sts, f_timestamp_rx
    }

    -- Create the subtree for `sband_tx_rx_sts_timestamp`
    local subtree = tree:add(sband_tx_rx_sts_timestamp, buffer(), "TM SBAND TX RX STS TIMESTAMP")

    -- Parse the `tx_index` and `rx_index`
    
    subtree:add(f_tx_index, buffer(offset, 2):le_uint())
    offset = offset + 2
    subtree:add(f_rx_index, buffer(offset, 2):le_uint())
    offset = offset + 2

    -- Parse the `tx_ts` array (50 entries of `s_sband_tx_sts_timestamp`)
    for i = 0, 49 do
        local tx_subtree = subtree:add(buffer(offset), "TX Info Index" .. i)

        -- Parse `tx_sts` (1 byte)
        tx_subtree:add(f_tx_sts, buffer(offset, 1):le_uint())
        offset = offset + 1

        -- Parse `timestamp` (8 bytes)
        tx_subtree:add(f_timestamp_tx, buffer(offset, 8):le_uint64())
        offset = offset + 8
    end

    -- Parse the `rx_ts` array (50 entries of `s_sband_rx_sts_timestamp`)
    for i = 0, 49 do
        local rx_subtree = subtree:add(buffer(offset), "RX Info Index" .. i)

        -- Parse `rx0_sts` (1 byte)
        rx_subtree:add(f_rx0_sts, buffer(offset, 1):le_uint())
        offset = offset + 1

        -- Parse `rx1_sts` (1 byte)
        rx_subtree:add(f_rx1_sts, buffer(offset, 1):le_uint())
        offset = offset + 1

        -- Parse `timestamp` (8 bytes)
        rx_subtree:add(f_timestamp_rx, buffer(offset, 8):le_uint64())
        offset = offset + 8
    end
end
